(sec-tskit2zarr-cli-ref)=
# CLI Reference

% A note on cross references... There's some weird long-standing problem with
% cross referencing program values in Sphinx, which means that we can't use
% the built-in labels generated by sphinx-click. We can make our own explicit
% targets, but these have to have slightly weird names to avoid conflicting
% with what sphinx-click is doing. So, hence the cmd- prefix.
% Based on: https://github.com/skypilot-org/skypilot/pull/2834

```{eval-rst}

.. _cmd-tskit2zarr-convert:
.. click:: bio2zarr.cli:convert_tskit
   :prog: tskit2zarr convert
   :nested: full

```
